@@ -5,6 +5,7 @@
 ##########################################################################
 
 import os
+import sys
 
 from util import newTempfile, runcmd
 from logger import LOG
@@ -37,7 +38,11 @@ class PDFConverter(object):
         if not output_filename:
             output_filename = newTempfile(suffix='.pdf')
 
-        cmd = '"%s/bin/unix/xinc" -fo "%s" -pdf "%s"' % (xinc_home, fo_filename, output_filename)
+        if sys.platform == 'win32':
+            cmd = '%s\\xinc.exe -fo "%s" -pdf "%s"' % (xinc_home, fo_filename, output_filename)
+        else:
+            cmd = '"%s/bin/unix/xinc" -fo "%s" -pdf "%s"' % (xinc_home, fo_filename, output_filename)
+
         status, output = runcmd(cmd)
         if status != 0:
             raise RuntimeError('Error executing: %s' % cmd)
